@@ -1,17 +1,11 @@
+use crate::utils::spinner_data::SpinnerData;
 use lazy_static::lazy_static;
 use maplit::{self, hashmap};
 use std::collections::HashMap;
-
-#[derive(Debug, Clone)]
-pub struct SpinnerData {
-    pub frames: Vec<&'static str>,
-    pub interval: u16,
-}
-
 lazy_static! {
     pub static ref SPINNERS: HashMap<String, SpinnerData> = {
         hashmap! {
-        "Dots".into() => SpinnerData {frames: vec![
+              "Dots".into() => SpinnerData {frames: vec![
           "⠋",
           "⠙",
           "⠹",
